@@ -49,7 +49,11 @@ checkpoint <- function(snapshotDate, project = getwd(), verbose=TRUE) {
 
   # Scan for packages used
   mssg(verbose, "Scanning for packages used in this project")
-  packages.to.install = projectScanPackages(project)
+  exclude.packages = c("checkpoint", # this very package
+                       c("base", "compiler", "datasets", "graphics", "grDevices", "grid",
+                         "methods", "parallel", "splines", "stats", "stats4", "tcltk",
+                         "tools", "utils"))  # all base priority packages, not on CRAN or MRAN
+  packages.to.install = setdiff(projectScanPackages(project), exclude.packages)
 
   # install missing packages
 
@@ -92,7 +96,7 @@ getSnapshotUrl <- function(snapshotDate, url = mranUrl()){
         stop(sprintf("Unable to reach MRAN: %s", e$message))})
   snapshot.url = paste(gsub("/$", "", url), snapshotDate, sep = "/")
   con = url(snapshot.url)
-  on.exit(close(con))
+  on.exit(close(con), add = TRUE)
   tryCatch(
     suppressWarnings(readLines(con)),
     error =
